==> xlniuxdata-vipgame-1.0.65-20170706.065031-93-sources.jar: com/xunlei/niux/data/vipgame/bo/GameSendGiftJinZuanBoImpl.java <==
package com.xunlei.niux.data.vipgame.bo;

import com.ferret.common.dao.BaseDao;
import com.ferret.common.dao.util.DaoUtil;
import com.ferret.common.dao.vo.Page;
import com.xunlei.niux.data.vipgame.vo.sendgift.GameSendGiftJinzuan;
import com.xunlei.niux.data.vipgame.vo.sendgift.GameSendGiftRecord;
import com.xunlei.niux.data.vipgame.vo.sendgift.GameSendGiftSet;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by admin on 2017/6/14.
 */
public class GameSendGiftJinZuanBoImpl implements GameSendGiftJinZuanBo {
    private BaseDao baseDao;

    public BaseDao getBaseDao() {
        return baseDao;
    }

    public void setBaseDao(BaseDao baseDao) {
        this.baseDao = baseDao;
    }
    @Override
    public void save(GameSendGiftSet gameSendGiftSet, List<GameSendGiftJinzuan> list) {
        baseDao.insert(gameSendGiftSet);
        for(GameSendGiftJinzuan gsgj:list){
            baseDao.insert(gsgj);
        }
    }

    @Override
    public void update(GameSendGiftSet gameSendGiftSet, List<GameSendGiftJinzuan> list) {
        baseDao.updateById(gameSendGiftSet);
      /*  for(GameSendGiftJinzuan gsgj:list){
            if(gsgj.getSeqId()!=null){
                baseDao.deleteById(GameSendGiftJinzuan.class,gsgj.getSeqId());
            }

        }*/
        String tableName = DaoUtil.getTableName(GameSendGiftJinzuan.class);
        List<Object> paramsList = new ArrayList();
        paramsList.add(gameSendGiftSet.getGameId());
        String sql = "delete from "+tableName+" where gameId=?";
        baseDao.execute(sql,paramsList);
        for(GameSendGiftJinzuan gsgj:list){
            baseDao.insert(gsgj);
        }
    }

    @Override
    public void updateGameSendGiftSet(GameSendGiftSet gameSendGiftSet) {
        baseDao.updateById(gameSendGiftSet);
    }

    @Override
    public void updateGameSendGiftJinzuan(GameSendGiftJinzuan gameSendGiftJinzuan) {
        baseDao.updateById(gameSendGiftJinzuan);
    }

    @Override
    public boolean checkUserSendGiftRecord(GameSendGiftRecord gameSendGiftRecord) {
        int count = baseDao.count(gameSendGiftRecord);
        if(count>0){
           return false;
        }
        return true;
    }

    @Override
    public void saveSendGiftRecord(GameSendGiftRecord gameSendGiftRecord) {
        baseDao.insert(gameSendGiftRecord);
    }

//    @Override
//    public void updateSendGiftStatus(GameSendGiftRecord gameSendGiftRecord) {
//        String tableName = DaoUtil.getTableName(gameSendGiftRecord.getClass());
//        String sql =  "update "+tableName+" set successTime=?,"
//
//    }


}

==> xlniuxdata-vipgame-1.0.65-20170706.090450-94-sources.jar: com/xunlei/niux/data/vipgame/bo/GameSendGiftJinZuanBoImpl.java <==
package com.xunlei.niux.data.vipgame.bo;

import com.ferret.common.dao.BaseDao;
import com.ferret.common.dao.util.DaoUtil;
import com.ferret.common.dao.vo.Page;
import com.xunlei.niux.data.vipgame.vo.sendgift.GameSendGiftJinzuan;
import com.xunlei.niux.data.vipgame.vo.sendgift.GameSendGiftRecord;
import com.xunlei.niux.data.vipgame.vo.sendgift.GameSendGiftSet;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by admin on 2017/6/14.
 */
public class GameSendGiftJinZuanBoImpl implements GameSendGiftJinZuanBo {
    private BaseDao baseDao;

    public BaseDao getBaseDao() {
        return baseDao;
    }

    public void setBaseDao(BaseDao baseDao) {
        this.baseDao = baseDao;
    }
    @Override
    public void save(GameSendGiftSet gameSendGiftSet, List<GameSendGiftJinzuan> list) {
        baseDao.insert(gameSendGiftSet);
        for(GameSendGiftJinzuan gsgj:list){
            baseDao.insert(gsgj);
        }
    }

    @Override
    public void update(GameSendGiftSet gameSendGiftSet, List<GameSendGiftJinzuan> list) {
        baseDao.updateById(gameSendGiftSet);
      /*  for(GameSendGiftJinzuan gsgj:list){
            if(gsgj.getSeqId()!=null){
                baseDao.deleteById(GameSendGiftJinzuan.class,gsgj.getSeqId());
            }

        }*/
        String tableName = DaoUtil.getTableName(GameSendGiftJinzuan.class);
        List<Object> paramsList = new ArrayList();
        paramsList.add(gameSendGiftSet.getGameId());
        String sql = "delete from "+tableName+" where gameId=?";
        baseDao.execute(sql,paramsList);
        for(GameSendGiftJinzuan gsgj:list){
            baseDao.insert(gsgj);
        }
    }

    @Override
    public void updateGameSendGiftSet(GameSendGiftSet gameSendGiftSet) {
        baseDao.updateById(gameSendGiftSet);
    }

    @Override
    public void updateGameSendGiftJinzuan(GameSendGiftJinzuan gameSendGiftJinzuan) {
        baseDao.updateById(gameSendGiftJinzuan);
    }

    @Override
    public boolean checkUserSendGiftRecord(GameSendGiftRecord gameSendGiftRecord) {
        GameSendGiftRecord query = new GameSendGiftRecord();
        query.setGiftId(gameSendGiftRecord.getGiftId());
        query.setUid(gameSendGiftRecord.getUid());
        query.setGameId(gameSendGiftRecord.getGameId());
        query.setServerId(gameSendGiftRecord.getServerId());
        query.setRoleId(gameSendGiftRecord.getRoleId());
        int count = baseDao.count(gameSendGiftRecord);
        if(count>0){
           return false;
        }
        return true;
    }

    @Override
    public void saveSendGiftRecord(GameSendGiftRecord gameSendGiftRecord) {
        baseDao.insert(gameSendGiftRecord);
    }

//    @Override
//    public void updateSendGiftStatus(GameSendGiftRecord gameSendGiftRecord) {
//        String tableName = DaoUtil.getTableName(gameSendGiftRecord.getClass());
//        String sql =  "update "+tableName+" set successTime=?,"
//
//    }


}
